==> haskell-mono-traversable-instances-0.1.1.0-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-JbwIaTC4d4lIPzC6nBazeC
key:                  mono-traversable-instances-0.1.1.0-JbwIaTC4d4lIPzC6nBazeC
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  915071e6d66229285124e6cc52cc43b9
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-JbwIaTC4d4lIPzC6nBazeC
depends:
    base-4.16.4.0 comonad-5.0.8-7SvbYtos92D1jPcdvHdUhM
    containers-0.6.5.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    dlist-instances-0.1.1.1-JslKp8mS5wKJOXBnE4qAqH
    mono-traversable-1.0.20.0-BbUSWYcXr8M9RkrkturSr4
    semigroupoids-5.3.7-CmdCtkiMB79IiDSsUdUQis transformers-0.5.6.2
    vector-instances-3.4.2-HpDyj2K1BD5I1fS8DcGSCH

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-instances-0.1.1.0-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-6KMUMNBhZDTAdXjtKi0LO8
key:                  mono-traversable-instances-0.1.1.0-6KMUMNBhZDTAdXjtKi0LO8
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  a768562b6a00f9b0cfa0216f13869a1a
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-6KMUMNBhZDTAdXjtKi0LO8
depends:
    base-4.16.4.0 comonad-5.0.8-FPX8fqTXWBRIN28hv9cMY3
    containers-0.6.5.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    dlist-instances-0.1.1.1-JslKp8mS5wKJOXBnE4qAqH
    mono-traversable-1.0.20.0-J6fjWUAJ9gbHTPdUl9CoqX
    semigroupoids-5.3.7-DRrQ6HM3i3lBidmriDf0rx transformers-0.5.6.2
    vector-instances-3.4.2-8o6D7OJpj24JRsFHE2kVcX

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
